/*
 * Segment 8 Parametrierung und Konfiguration, SWE 8.2 Parametrierung
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.puk.param.param;

import java.util.ResourceBundle;
import java.util.logging.Level;

import de.bsvrz.sys.funclib.bitctrl.daf.LogNachricht;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.operatingMessage.MessageGrade;

/**
 * die allgemeinen Meldungen innerhalb der Softwareeinheit "Umfassende
 * Datenanalyse".
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public enum ParamMessage implements LogNachricht {

	/* Meldungen die mit dem Level ERROR ausgegeben werden sollen . */

	/** Parameter 1) Meldung der Exception. */
	ErrorLesenAnfrageDaten(Debug.ERROR),

	/**
	 * Parameter 1) Meldung der Exception. 2) Meldung des Grunds der Exception.
	 */
	ErrorInitialisiereDerbyDb(Debug.ERROR),

	/** Parameter 1) Meldung der Exception. */
	ErrorCloseDerbyDb(Debug.ERROR),

	/** Parameter 1) Objekt 2) ATG 3) SimVariante 4) Fehlermeldung. */
	ErrorLoescheDatensatzDerbyDb(Debug.ERROR),

	/** Parameter 1) Objekt 2) ATG 3) SimVariante 4) Fehlermeldung. */
	ErrorLesenDatensatzDerbyDb(Debug.ERROR),

	/** Parameter 1) Objekt 2) ATG 3) SimVariante 4) Fehlermeldung. */
	ErrorSchreibenDatensatzDerbyDb(Debug.ERROR),

	/** Parameter 1) Fehlermeldung. */
	ErrorSchreibenDatensatz(Debug.ERROR),

	/** Parameter 1) SimVariante 2) Fehlermeldung. */
	ErrorLoescheSimVarianteDerbyDb(Debug.ERROR),

	/** Parameter 1) Fehlermeldung. */
	ErrorLesenBlobDerbyDb(Debug.ERROR),

	/** Parameter 1) Name des Verzeichnis. */
	ErrorEntfernenVerzeichnis(Debug.ERROR),

	/** Parameter 1) Name des Verzeichnis. */
	ErrorAnlegenSimulationsVerzeichnis(Debug.ERROR),

	/** Parameter 1) Thread 2) Grund. */
	ErrorParamAbbruch(Debug.ERROR),

	/** Parameter 1) Simulation 2) Grund. */
	ErrorAnlegenSimulationsHandler(Debug.ERROR),

	/** Parameter 1) Simulation 2) Grund. */
	ErrorBereitschaftSimulation(Debug.ERROR),

	/** Parameter 1) Fehlermeldung. */
	ErrorSendeAnmeldungAntwort(Debug.ERROR),

	/** Parameter 1) Objekt 2) Attributgruppe 3) SimVariante. */
	ErrorKeineParameterDaten(Debug.ERROR),

	/** Parameter 1) Simulation. */
	ErrorSimulationAbmeldungBeiAktiv(Debug.ERROR),

	/** Parameter 1) Dateiname. */
	ErrorDefekteParameterDatei(Debug.ERROR),

	/** Parameter 1) Parameterspezifikation. */
	ErrorSendeAnmeldung(Debug.ERROR),

	/**
	 * Parameter 1) Parameterspezifikation 2) Text der auslösenden Exception.
	 */
	ErrorSendeAnmeldungWithException(Debug.ERROR),

	/* Meldungen die mit dem Level ERROR ausgegeben werden sollen . */

	/** Parameter 1) Objekteintrag 2) Typeintrag. */
	WarningFalscheTypKombination(Debug.WARNING),

	/** Parameter 1) Parameterspezifikation 2) Datensatz. */
	WarningUnvollstaendigerDatensatz(Debug.WARNING),

	/** Parameter 1) Simulation 2) Zustand. */
	WarningUngueltigerSimulationsZustand(Debug.WARNING);

	/**
	 * das verwendete Ressource-Bundle.
	 */
	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle
			.getBundle(ParamMessage.class.getCanonicalName());

	/** der Level mit dem die Meldung ausgegeben werden soll. */
	private Level level;

	/**
	 * Initialisiert das Objekt.
	 *
	 * @param level
	 *            der Log-Level.
	 */
	ParamMessage(final Level level) {
		this.level = level;
	}

	@Override
	public MessageGrade getBmvLevel() {
		return null;
	}

	@Override
	public Level getLogLevel() {
		return level;
	}

	@Override
	public ResourceBundle getResourceBundle() {
		return ParamMessage.RESOURCE_BUNDLE;
	}

	@Override
	public String toString() {
		return getResourceBundle().getString(name());
	}

}
